==> comm100_live_chat-7.x-1.0.tar.gz: comm100_live_chat/Comm100.php <==
<?php
/**
 * @file
 * Comm100 Live Chat module for Drupal.
 */

class Comm100 {
  protected static $instance = NULL;
  /**
   * Module directory.
   */
  protected $moduleDir = NULL;
  /**
   * Instance.
   */
  public static function getInstance() {
    if (is_null(self::$instance)) {
      self::$instance = new Comm100();
    }
    return self::$instance;
  }
  /**
   * Constructor.
   */
  protected function __construct() {
    $this->moduleDir = drupal_get_path('module', 'Comm100');
  }
  /**
   * Resets module settings.
   */
  public function resetSettings() {
    variable_del('actiontype');
    variable_del('email');
    variable_del('password');
    variable_del('plan_id');
    variable_del('plan_type');
    variable_del('postdatatype');
    variable_del('register_email');
    variable_del('register_ip');
    variable_del('register_name');
    variable_del('register_password');
    variable_del('register_password_retype');
    variable_del('register_phone');
    variable_del('register_website');
    variable_del('txtCurrentStep');
    variable_del('login_email');
    variable_del('login_password');
    variable_set('comm100_siteid', '0');
    variable_set('comm100_codeplanid', '0');
    variable_set('comm100_codeplantype', '0');
    variable_set('comm100_email', '');
    variable_set('comm100_password', '');
    variable_set('comm100_actiontype', '4');
  }
  /**
   * License number validation.
   */
  public function validateSiteid($siteid) {
    $siteid = (int) $siteid;
    if ($siteid === 0) {
      return FALSE;
    }
    return TRUE;
  }
  /**
   * Checks if Livechat settings are properly set up.
   */
  public function isInstalled() {
    $comm100_siteid = variable_get('comm100_siteid');
    if (is_null($comm100_siteid)) {
      return FALSE;
    }
    return $this->validateSiteid($comm100_siteid);
  }
  /**
   * Install code.
   */
  public function installCodes() {
    $this->addCode();
  }
  /**
   * Add code.
   */
  public function addCode() {
    if ($this->isInstalled() == FALSE) {
      return FALSE;
    }
    $path = $this->moduleDir . '/codes/code.txt';
    if (!file_exists($path)) {
      return;
    }
    $code = file_get_contents($path);
    $code = str_replace(
      array('{%SITEID%}'),
      array(variable_get('comm100_siteid')),
      $code);
    $code = str_replace(
      array('{%CODEPLAN%}'),
      array(variable_get('comm100_codeplanid')),
      $code);
    $comm100_codeplantype = variable_get('comm100_codeplantype');
    if ($comm100_codeplantype == 0 || $comm100_codeplantype == 1) {
      drupal_add_js($code, array(
        'type' => 'inline',
        'scope' => 'footer',
        'weight' => 5));
    }
  }
  /**
   * Includes admin CSS file.
   */
  public function includeAdminCss() {
    drupal_add_css($this->moduleDir . '/css/comm100.css');
  }
  /**
   * Includes admin JS file.
   */
  public function includeAdminJs() {
    drupal_add_js('https://hosted.comm100.com/AdminPluginService/livechatplugin.ashx?action=session');
    drupal_add_js($this->moduleDir . '/js/plugin.js');
  }
}

==> comm100_live_chat-7.x-1.1.tar.gz: comm100_live_chat/Comm100.php <==
<?php
/**
 * @file
 * Comm100 Live Chat module for Drupal.
 */

class Comm100 {
  protected static $instance = NULL;
  /**
   * Module directory.
   */
  protected $moduleDir = NULL;
  /**
   * Instance.
   */
  protected $plugin_url = null;
  protected $site_id = null;
  protected $email = null;
  protected $plan_id = null;
  protected $plan_type = null;   //float button 0, monitor 1, others 2
  protected $cpanel_domain = null;
  protected $main_chatserver_domain = null;
  protected $standby_chatserver_domain = null;
  public static function getInstance() {
    if (is_null(self::$instance)) {
      self::$instance = new Comm100();
    }
    return self::$instance;
  }
  /**
   * Constructor.
   */
  protected function __construct() {
    $this->moduleDir = drupal_get_path('module', 'Comm100');
  }
  /**
   * Resets module settings.
   */
  public function resetSettings() {
    variable_del('actiontype');
    variable_del('email');
    variable_del('password');
    variable_del('plan_id');
    variable_del('plan_type');
    variable_del('postdatatype');
    variable_del('register_email');
    variable_del('register_ip');
    variable_del('register_name');
    variable_del('register_password');
    variable_del('register_password_retype');
    variable_del('register_phone');
    variable_del('register_website');
    variable_del('txtCurrentStep');
    variable_del('login_email');
    variable_del('login_password');
    variable_set('comm100_siteid', '0');
    variable_set('comm100_codeplanid', '0');
    variable_set('comm100_codeplantype', '0');
    variable_set('comm100_email', '');
    variable_set('comm100_password', '');
    variable_set('comm100_actiontype', '4');
	variable_set('comm100_cpanel_domain', '');
	variable_set('comm100_main_chatserver_domain', '');
	variable_set('comm100_standby_chatserver_domain', '');
  }
  public function get_cpanel_domain() 
  {
	if (is_null($this->cpanel_domain))
	{
		$this->cpanel_domain = get_option('comm100livechat_cpanel_domain');
	}
	return $this->cpanel_domain;
  }
  public function get_main_chatserver_domain() 
  {
	if (is_null($this->main_chatserver_domain))
	{
		$this->main_chatserver_domain = get_option('comm100livechat_main_chatserver_domain');
	}
	return $this->main_chatserver_domain;
  }
  public function get_standby_chatserver_domain() 
  {
	if (is_null($this->standby_chatserver_domain))
	{
		$this->standby_chatserver_domain = get_option('comm100livechat_standby_chatserver_domain');
	}
	return $this->standby_chatserver_domain;
  }
  /**
   * License number validation.
   */
  public function validateSiteid($siteid) {
    $siteid = (int) $siteid;
    if ($siteid === 0) {
      return FALSE;
    }
    return TRUE;
  }
  /**
   * Checks if Livechat settings are properly set up.
   */
  public function isInstalled() {
    $comm100_siteid = variable_get('comm100_siteid');
    if (is_null($comm100_siteid)) {
      return FALSE;
    }
    return $this->validateSiteid($comm100_siteid);
  }
  /**
   * Install code.
   */
  public function installCodes() {
    $this->addCode();
  }
  /**
   * Add code.
   */
  public function addCode() {
    if ($this->isInstalled() == FALSE) {
      return FALSE;
    }
    $path = $this->moduleDir . '/codes/code.txt';
    if (!file_exists($path)) {
      return;
    }
    $code = file_get_contents($path);
    $code = str_replace(
      array('{%SITEID%}'),
      array(variable_get('comm100_siteid')),
      $code);
    $code = str_replace(
      array('{%CODEPLAN%}'),
      array(variable_get('comm100_codeplanid')),
      $code);
	$code = str_replace(
	  array('{%MAIN_CHATSERVER_DOMAIN%}'),
	  array(variable_get('comm100_main_chatserver_domain')),
	  $code);
	$code = str_replace(
	  array('{%STANDBY_CHATSERVER_DOMAIN%}'),
	  array(variable_get('comm100_standby_chatserver_domain')),
	  $code);
    $comm100_codeplantype = variable_get('comm100_codeplantype');
    if ($comm100_codeplantype == 0 || $comm100_codeplantype == 1) {
      drupal_add_js($code, array(
        'type' => 'inline',
        'scope' => 'footer',
        'weight' => 5));
    }
  }
  /**
   * Includes admin CSS file.
   */
  public function includeAdminCss() {
    drupal_add_css($this->moduleDir . '/css/comm100.css');
  }
  /**
   * Includes admin JS file.
   */
  public function includeAdminJs() {
    //drupal_add_js('https://host.comm100.com/AdminPluginService/livechatplugin.ashx?action=session');
    drupal_add_js($this->moduleDir . '/js/plugin.js');
  }
}
